#!/bin/bash  -x
set -o nounset
outFile="/tmp/sensorPolicy.xml"
errFile="/tmp/setschema.log"
schemasJarPath="/var/www/lmi/public/schemas"
schemajar="schemas5_0.jar"

nameSpace=""
schemaVersion=""
spi=""
DB_CONF="/etc/iss/iss-dbd.conf"

function  AddSignificantEvent
{
  STRINGID=$1
  Desc=$2
  if [ -f $DB_CONF ]; then
    CRMDB=$(cat $DB_CONF | grep -w CRMDatabase | awk -F = '{print $2}')
    sqlite3 $CRMDB "insert into systemevents (ID, StringID, Component, Occurred, EventValue) values((select max(rowid) from systemevents),(select ID from strings where CodeID='$STRINGID'), 'PATCH', DATETIME('NOW'),'$2');"
  fi

}

while getopts "s:n:p:" opt; do
  case $opt in
    s ) schemaVersion=$OPTARG ;;
    n ) nameSpace=$OPTARG ;;
    p ) spi=$OPTARG ;;
  esac
done

if [ -f $errFile ]; then
  rm $errFile
fi

if [ $nameSpace = "" ] || [ $schemaVersion = "" ] || [ $spi = "" ]; then
	echo "usage $0 -s schemaVersion -n nameSpace -p sensorPolicyInfo_file"
	exit 1
fi


if [ -f $outFile ]; then
  echo "removing $outFile" >> $errFile
  rm $outFile
fi

if [ -f $spi ]; then
	cp $spi $spi.001
	echo "Copying $spi to $spi.001" >> $errFile
fi

#  Run the transform
Xalan -o $outFile -p paramSchemaVersion "'$schemaVersion'" -p paramNameSpace "'$nameSpace'" $spi /etc/crm/transforms/xslt/SensorPolicyInfo_1.2_Mod_Compatible.xslt 2>> $errFile
result=$?
if [ $result -eq 0 ]; then
   mv $outFile $spi
else
   echo "Transforming $spi has failed.  Xalan returned $result" >> $errFile
   exit $result
fi

# Test the result.  Ensure that the file can be reread and that the version
# attribute did change.
#
changedVersion=`Xalan $spi /etc/crm/transforms/xslt/SensorPolicyInfo_1.1_List.xslt | grep $nameSpace | awk -F , '{print $6}'`
result=$?
if [ $result != "0" ]; then
  cp $spi.001 $spi
  echo "ERROR:  Test of transform file failed." >> $errFile
  exit 1
fi

if [ "$changedVersion" != "$schemaVersion" ]; then
  cp $spi.001 $spi
  echo "ERROR:  Test of transform file failed.  Versions don't match. $changedVersion was read from $spi" >> $errFile
  exit 1
else
  echo "Schema version succesfully changed to $changedVersion for $nameSpace" >> $errFile
fi
result="1"
# rebuild the schemas.jar file
if [ -f $schemasJarPath/$schemajar ]; then
	echo "Building the jar." >> $errFile
	cp $schemasJarPath/$schemajar $schemasJarPath/$schemajar.001
	cd /etc/crm/schemas
	/usr/bin/zip -qr $schemasJarPath/$schemajar cml Iss1_0_0.xsd Iss1_0_1.xsd
	result=$?
	cd -
	if [ $result != "0" ]; then
		echo "Error building jar '$schemajar'" >> $errFile
		cp $schemasJarPath/$schemajar.001 $schemasJarPath/$schemajar
		rm  $schemasJarPath/$schemajar.001
	else
	  echo "Creating significant event." >> $errFile
	  AddSignificantEvent CRM_SET_SCHEMA "Version: $schemaVersion  Namespace:  $nameSpace"
	fi
fi



